### 0.1.2 (2013-09-04)

- sync up with Hemlock 0.1.2

### 0.1.1 (2013-08-23)

- small additions to API to keep up with Hemlock API changes

### 0.1.0 (2013-08-12)

- basic RESTful implementation that leverages the existing Hemlock CLI API
